module.exports={A:{A:{"2436":"K D E F A B 6C"},B:{"260":"O P","2436":"C L M G N","8196":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I"},C:{"2":"7C ZC J fB K D E F A B C L M G N O P gB CB DB AD BD","772":"EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB","4100":"0 1 2 3 4 5 6 7 8 9 sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C"},D:{"2":"J fB K D E F A B C","2564":"L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB","8196":"0 1 2 3 4 5 6 7 8 9 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC","10244":"uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B"},E:{"1":"C L M G UC HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","16":"CD fC","2308":"A B gC TC","2820":"J fB K D E F DD ED FD GD"},F:{"2":"F B OD PD QD RD TC 4C SD","16":"C","516":"UC","2564":"G N O P gB CB DB EB FB GB HB IB JB KB LB","8196":"0 1 2 3 4 5 6 7 8 9 wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB","10244":"hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB"},G:{"1":"eD fD gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","2":"fC TD 5C","2820":"E UD VD WD XD YD ZD aD bD cD dD"},H:{"2":"qD"},I:{"2":"ZC J rD sD tD uD 5C","260":"I","2308":"vD wD"},J:{"2":"D","2308":"A"},K:{"2":"A B C TC 4C","16":"UC","8196":"H"},L:{"8196":"I"},M:{"1028":"SC"},N:{"2":"A B"},O:{"8196":"VC"},P:{"2052":"xD yD","2308":"J","8196":"CB DB EB FB GB HB IB JB KB LB zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"8196":"8D"},R:{"8196":"9D"},S:{"4100":"AE BE"}},B:5,C:"Synchronous Clipboard API",D:true};
