module.exports={A:{A:{"2":"K D E 6C","520":"F A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I","8":"C L","388":"M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C","2":"7C ZC AD BD","132":"J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC","2":"J fB","132":"K D E F A B C L M G N O P gB CB DB EB FB GB"},E:{"2":"CD","8":"J fB fC DD","520":"K D E F A B C ED FD GD gC TC","16385":"WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","17412":"L UC HD","23556":"M","24580":"G ID JD hC iC VC KD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB","2":"F OD PD QD","132":"B C G RD TC 4C SD UC"},G:{"2":"E fC TD 5C UD VD WD XD YD ZD aD bD cD dD eD","16385":"rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","17412":"fD gD hD iD jD","19460":"kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC"},H:{"2":"qD"},I:{"1":"I","2":"rD sD","132":"ZC J tD uD 5C vD wD"},J:{"2":"D A"},K:{"1":"H","2":"A B C TC 4C UC"},L:{"1":"I"},M:{"1":"SC"},N:{"8":"A B"},O:{"1":"VC"},P:{"1":"CB DB EB FB GB HB IB JB KB LB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D","132":"J"},Q:{"1":"8D"},R:{"1":"9D"},S:{"1":"AE BE"}},B:6,C:"WebM video format",D:true};
