module.exports={A:{A:{"1":"B","4":"K D E F A 6C"},B:{"1":"C L M G N","129":"0 1 2 3 4 5 6 7 8 9 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I"},C:{"1":"K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B","4":"7C ZC J fB AD BD","129":"0 1 2 3 4 5 6 7 8 9 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C"},D:{"1":"wB xB yB zB 0B 1B 2B 3B 4B 5B","4":"J fB K","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC"},E:{"4":"J fB CD fC","129":"K D E F A B C L M G DD ED FD GD gC TC UC HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND"},F:{"1":"C jB kB lB mB nB oB pB qB rB sB TC 4C SD UC","4":"F B OD PD QD RD","129":"0 1 2 3 4 5 6 7 8 9 G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB"},G:{"4":"fC TD 5C","129":"E UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C"},H:{"4":"qD"},I:{"4":"rD sD tD","129":"ZC J I uD 5C vD wD"},J:{"129":"D A"},K:{"1":"C TC 4C UC","4":"A B","129":"H"},L:{"129":"I"},M:{"129":"SC"},N:{"1":"B","4":"A"},O:{"129":"VC"},P:{"129":"J CB DB EB FB GB HB IB JB KB LB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"129":"8D"},R:{"129":"9D"},S:{"1":"AE","129":"BE"}},B:1,C:"dataset & data-* attributes",D:true};
