module.exports={A:{A:{"2":"K D E F A B 6C"},B:{"2":"C L M G N O P","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I","1537":"Q H R S T U V W X Y Z a b c"},C:{"2":"7C","932":"ZC J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC AD BD","2308":"0 1 2 3 4 5 6 7 8 9 FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C"},D:{"2":"J fB K D E F A B C L M G N O P gB CB DB","545":"EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC","1537":"xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c"},E:{"1":"WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","2":"J fB K CD fC DD","516":"B C L M G TC UC HD ID JD hC iC VC KD","548":"F A GD gC","676":"D E ED FD"},F:{"2":"F B C OD PD QD RD TC 4C SD UC","513":"lB","545":"G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB","1025":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB BB","1537":"kB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d"},G:{"1":"WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","2":"fC TD 5C UD VD","516":"kD lD mD hC iC VC nD","548":"YD ZD aD bD cD dD eD fD gD hD iD jD","676":"E WD XD"},H:{"2":"qD"},I:{"2":"ZC J rD sD tD uD 5C","545":"vD wD","1025":"I"},J:{"2":"D","545":"A"},K:{"2":"A B C TC 4C UC","1025":"H"},L:{"1025":"I"},M:{"2308":"SC"},N:{"2":"A B"},O:{"1537":"VC"},P:{"545":"J","1025":"CB DB EB FB GB HB IB JB KB LB XC YC 7D","1537":"xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC"},Q:{"1537":"8D"},R:{"1537":"9D"},S:{"932":"AE","2308":"BE"}},B:5,C:"Intrinsic & Extrinsic Sizing",D:true};
