module.exports={A:{A:{"2":"K D E 6C","2561":"A B","2692":"F"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I","2561":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C","16":"7C","1537":"J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB BD","1796":"ZC AD"},D:{"1":"0 1 2 3 4 5 6 7 8 9 FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC","16":"J fB K D E F A B C L M","1025":"mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC","1537":"G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB"},E:{"1":"M G HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","16":"J fB K CD fC","1025":"D E F A B C ED FD GD gC TC","1537":"DD","4097":"L UC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB UC","16":"F B C OD PD QD RD TC 4C","260":"SD","1025":"EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B","1537":"G N O P gB CB DB"},G:{"1":"hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","16":"fC TD 5C","1025":"E XD YD ZD aD bD cD dD eD","1537":"UD VD WD","4097":"fD gD"},H:{"2":"qD"},I:{"16":"rD sD","1025":"I wD","1537":"ZC J tD uD 5C vD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C H TC 4C UC"},L:{"1":"I"},M:{"1":"SC"},N:{"2561":"A B"},O:{"1":"VC"},P:{"1025":"J CB DB EB FB GB HB IB JB KB LB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"1":"8D"},R:{"1":"9D"},S:{"1":"BE","1537":"AE"}},B:1,C:"input event",D:true};
