module.exports={A:{A:{"1":"A B","2":"K D E F 6C"},B:{"1":"C L M G N O P","516":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I"},C:{"132":"3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC","164":"7C ZC J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B AD BD","516":"EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a","1028":"0 1 2 3 4 5 6 7 8 9 b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C"},D:{"420":"J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B","516":"0 1 2 3 4 5 6 7 8 9 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC"},E:{"1":"A B C L M G gC TC UC HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","132":"F GD","164":"D E FD","420":"J fB K CD fC DD ED"},F:{"1":"C TC 4C SD UC","2":"F B OD PD QD RD","420":"G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB","516":"0 1 2 3 4 5 6 7 8 9 oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB"},G:{"1":"aD bD cD dD eD fD gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","132":"YD ZD","164":"E WD XD","420":"fC TD 5C UD VD"},H:{"1":"qD"},I:{"420":"ZC J rD sD tD uD 5C vD wD","516":"I"},J:{"420":"D A"},K:{"1":"C TC 4C UC","2":"A B","516":"H"},L:{"516":"I"},M:{"1028":"SC"},N:{"1":"A B"},O:{"516":"VC"},P:{"420":"J","516":"CB DB EB FB GB HB IB JB KB LB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"516":"8D"},R:{"516":"9D"},S:{"164":"AE BE"}},B:4,C:"CSS3 Multiple column layout",D:true};
