module.exports={A:{A:{"2":"F A B 6C","8":"K D E"},B:{"1":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I","2":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 6 7 8 9 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C","2":"7C","8":"ZC J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB AD BD","194":"yB zB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC","8":"J fB K D E F A B","257":"gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB","769":"C L M G N O P"},E:{"1":"C L M G UC HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","8":"J fB CD fC DD","257":"K D E F A ED FD GD","1025":"B gC TC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB","2":"C TC 4C SD UC","8":"F B OD PD QD RD"},G:{"1":"E VD WD XD YD ZD dD eD fD gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","8":"fC TD 5C UD","1025":"aD bD cD"},H:{"8":"qD"},I:{"1":"J I uD 5C vD wD","8":"ZC rD sD tD"},J:{"1":"A","8":"D"},K:{"1":"H","8":"A B C TC 4C UC"},L:{"1":"I"},M:{"1":"SC"},N:{"2":"A B"},O:{"1":"VC"},P:{"1":"J CB DB EB FB GB HB IB JB KB LB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"1":"8D"},R:{"1":"9D"},S:{"1":"AE BE"}},B:1,C:"Details & Summary elements",D:true};
