module.exports={A:{A:{"2":"F A B 6C","8":"K D E"},B:{"2":"C L M G N O P","8":"Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C","129":"7C ZC AD BD"},D:{"1":"GB","8":"J fB K D E F A B C L M G N O P gB CB DB EB FB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC"},E:{"1":"A B C L M G gC TC UC HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","260":"J fB K D E F CD fC DD ED FD GD"},F:{"2":"F","8":"G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC","584":"S T U V W X Y Z a b c d","1025":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB BB","2052":"B C OD PD QD RD TC 4C SD UC"},G:{"1":"E UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","8":"fC TD 5C"},H:{"8":"qD"},I:{"8":"ZC J rD sD tD uD 5C vD wD","1025":"I"},J:{"1":"A","8":"D"},K:{"8":"A B C TC 4C UC","1025":"H"},L:{"1025":"I"},M:{"1":"SC"},N:{"2":"A B"},O:{"8":"VC"},P:{"1":"DB EB FB GB HB IB JB KB LB","8":"J CB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"8":"8D"},R:{"8":"9D"},S:{"1":"AE BE"}},B:2,C:"MathML",D:true};
