module.exports={A:{A:{"2":"K D E 6C","260":"F A B"},B:{"2":"UB VB WB XB YB ZB aB bB cB dB eB I","66":"AB MB NB OB BB PB QB RB SB TB","132":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","260":"C L M G N O P"},C:{"2":"7C ZC J fB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C AD BD","260":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB"},D:{"2":"SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC","16":"J fB K D E F A B C L M","66":"AB MB NB OB BB PB QB RB","132":"0 1 2 3 4 5 6 7 8 9 G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},E:{"2":"yC zC 0C 1C 2C 3C ND","16":"CD fC","132":"J fB K D E F A B C L M G DD ED FD GD gC TC UC HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC"},F:{"1":"C SD UC","2":"F OD PD QD RD","16":"B TC 4C","66":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB","132":"G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v"},G:{"2":"yC zC 0C 1C 2C 3C","16":"fC TD","132":"E 5C UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC"},H:{"2":"qD"},I:{"2":"I","16":"rD sD","132":"ZC J tD uD 5C vD wD"},J:{"132":"D A"},K:{"1":"C UC","2":"A","16":"B TC 4C","132":"H"},L:{"2":"I"},M:{"2":"SC"},N:{"260":"A B"},O:{"132":"VC"},P:{"132":"J CB DB EB FB GB HB IB JB KB LB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"132":"8D"},R:{"132":"9D"},S:{"260":"AE BE"}},B:7,C:"Mutation events",D:true};
