module.exports={A:{A:{"2":"K 6C","2340":"D E F A B"},B:{"2":"C L M G N O P","1025":"0 1 2 3 4 5 6 7 8 9 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C","2":"7C ZC AD","513":"EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b","545":"J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC BD"},D:{"2":"J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB","1025":"0 1 2 3 4 5 6 7 8 9 sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B aC AC bC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC"},E:{"1":"A B C L M G gC TC UC HD ID JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","2":"J fB CD fC DD","164":"K","4644":"D E F ED FD GD"},F:{"2":"F B G N O P gB CB DB EB FB GB HB IB JB OD PD QD RD TC 4C","545":"C SD UC","1025":"0 1 2 3 4 5 6 7 8 9 KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB"},G:{"1":"aD bD cD dD eD fD gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","2":"fC TD 5C","4260":"UD VD","4644":"E WD XD YD ZD"},H:{"2":"qD"},I:{"2":"ZC J rD sD tD uD 5C vD wD","1025":"I"},J:{"2":"D","4260":"A"},K:{"2":"A B TC 4C","545":"C UC","1025":"H"},L:{"1025":"I"},M:{"1":"SC"},N:{"2340":"A B"},O:{"1025":"VC"},P:{"1025":"J CB DB EB FB GB HB IB JB KB LB xD yD zD 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"1025":"8D"},R:{"1025":"9D"},S:{"1":"BE","4097":"AE"}},B:4,C:"Crisp edges/pixelated images",D:true};
