module.exports={A:{A:{"2":"K D E F A B 6C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I","2":"C L M G N"},C:{"2":"7C ZC J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B AD BD","4609":"BC CC DC EC FC GC HC IC JC","4674":"bC","5698":"AC","7490":"4B 5B 6B 7B 8B","7746":"9B aC","8705":"0 1 2 3 4 5 6 7 8 9 KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC 8C 9C"},D:{"1":"0 1 2 3 4 5 6 7 8 9 GC HC IC JC KC LC MC NC OC PC QC RC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB MB NB OB BB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB eB I dC SC eC","2":"J fB K D E F A B C L M G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B","4097":"FC","4290":"aC AC bC","6148":"BC CC DC EC"},E:{"1":"G JD hC iC VC KD WC jC kC lC mC nC LD XC oC pC qC rC sC MD YC tC uC vC wC xC yC zC 0C 1C 2C 3C ND","2":"J fB K D E F A CD fC DD ED FD GD gC","4609":"B C TC UC","8193":"L M HD ID"},F:{"1":"0 1 2 3 4 5 6 7 8 9 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC RC Q H R cC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z AB BB","2":"F B C G N O P gB CB DB EB FB GB HB IB JB KB LB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB OD PD QD RD TC 4C SD UC","4097":"4B","6148":"0B 1B 2B 3B"},G:{"1":"gD hD iD jD kD lD mD hC iC VC nD WC jC kC lC mC nC oD XC oC pC qC rC sC pD YC tC uC vC wC xC yC zC 0C 1C 2C 3C","2":"E fC TD 5C UD VD WD XD YD ZD aD bD","4097":"cD dD eD fD"},H:{"2":"qD"},I:{"1":"I","2":"ZC J rD sD tD uD 5C vD wD"},J:{"2":"D A"},K:{"1":"H","2":"A B C TC 4C UC"},L:{"1":"I"},M:{"4097":"SC"},N:{"2":"A B"},O:{"1":"VC"},P:{"2":"J xD yD zD","4097":"CB DB EB FB GB HB IB JB KB LB 0D 1D gC 2D 3D 4D 5D 6D WC XC YC 7D"},Q:{"1":"8D"},R:{"1":"9D"},S:{"1":"BE","2":"AE"}},B:5,C:"Variable fonts",D:true};
